@@ -15,6 +15,8 @@ def _spark():
 
     spark = SparkSession \
         .builder.appName("Metrics-Transformer => - Data ETL Glue") \
+        .config("hive.exec.dynamic.partition", "true") \
+        .config("hive.exec.dynamic.partition.mode", "nonstrict") \
         .enableHiveSupport() \
         .getOrCreate()
 
